@@ -14,12 +14,14 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import mock
+from unittest import mock
 
+import netaddr
 from neutron.tests import base
 from neutron_lib.callbacks import events
 from neutron_lib.callbacks import registry
 from neutron_lib.callbacks import resources
+from neutron_lib import constants as n_const
 
 from neutron_dynamic_routing.api.rpc.callbacks import resources as dr_resources
 from neutron_dynamic_routing.db import bgp_db
@@ -34,7 +36,7 @@ class TestBgpPlugin(base.BaseTestCase):
                                   'agentnotifiers.bgp_dr_rpc_agent_api.'
                                   'BgpDrAgentNotifyApi')
         bgp_notify_p.start()
-        rpc_conn_p = mock.patch('neutron.common.rpc.create_connection')
+        rpc_conn_p = mock.patch('neutron_lib.rpc.Connection')
         rpc_conn_p.start()
         admin_ctx_p = mock.patch('neutron_lib.context.get_admin_context')
         self.admin_ctx_m = admin_ctx_p.start()
@@ -66,6 +68,8 @@ class TestBgpPlugin(base.BaseTestCase):
                           resources.ROUTER_GATEWAY, events.AFTER_CREATE),
                 mock.call(plugin.router_gateway_callback,
                           resources.ROUTER_GATEWAY, events.AFTER_DELETE),
+                mock.call(plugin.port_callback,
+                          resources.PORT, events.AFTER_UPDATE),
             ]
             self.assertEqual(subscribe.call_args_list, expected_calls)
 
@@ -86,3 +90,33 @@ class TestBgpPlugin(base.BaseTestCase):
                                                events.AFTER_CREATE,
                                                self.plugin,
                                                payload=payload)
+
+    def test_floatingip_update_callback(self):
+        kwargs = {'floating_ip_address': netaddr.IPAddress('10.10.10.10'),
+            'last_known_router_id': 'old-router-id',
+            'router_id': '', 'floating_network_id': 'a-b-c-d-e'}
+
+        test_context = 'test_context'
+
+        get_bpg_speakers_name = '_bgp_speakers_for_gw_network_by_family'
+        with mock.patch.object(self.plugin, get_bpg_speakers_name) as get_bgp:
+            with mock.patch.object(self.plugin,
+                                   'stop_route_advertisements') as stop_ad:
+                with mock.patch.object(self.plugin, '_bgp_rpc') as bgp_rpc:
+                    bgp_speaker = mock.Mock()
+                    bgp_speaker.id = '11111111-2222-3333-4444-555555555555'
+                    get_bgp.return_value = [bgp_speaker]
+
+                    self.plugin.floatingip_update_callback(
+                        test_context, events.AFTER_UPDATE, None, **kwargs)
+
+                    get_bgp.assert_called_once_with(self.fake_admin_ctx,
+                                                    'a-b-c-d-e',
+                                                    n_const.IP_VERSION_4)
+
+                    old_host_route = [{'destination': '10.10.10.10/32',
+                        'next_hop': None}]
+                    stop_ad.assert_called_once_with(self.fake_admin_ctx,
+                                                    bgp_rpc,
+                                                    bgp_speaker.id,
+                                                    old_host_route)
